[dpdk-dev] [PATCH] ethdev: fix comments for offload capabilites

Wei Dai wei.dai at intel.com
Thu Feb 1 12:21:42 CET 2018


Indeed, rx_offload_capa or tx_offload_capa  in struct rte_eth_dev_info
includes not only per port offloading features but also per queue ones.
This patch make its meaning much clearer.

Fixes: ce17eddefc20 ("ethdev: introduce Rx queue offloads API")
Fixes: cba7f53b717d ("ethdev: introduce Tx queue offloads API")
Cc: stable at dpdk.org
Signed-off-by: Wei Dai <wei.dai at intel.com>
---
 lib/librte_ether/rte_ethdev.h | 6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)

diff --git a/lib/librte_ether/rte_ethdev.h b/lib/librte_ether/rte_ethdev.h
index 0361533..6ab6552 100644
--- a/lib/librte_ether/rte_ethdev.h
+++ b/lib/librte_ether/rte_ethdev.h
@@ -1006,9 +1006,11 @@ struct rte_eth_dev_info {
 	uint16_t max_vfs; /**< Maximum number of VFs. */
 	uint16_t max_vmdq_pools; /**< Maximum number of VMDq pools. */
 	uint64_t rx_offload_capa;
-	/**< Device per port RX offload capabilities. */
+	/**< Rx offload capabilities including all per port ones
+		and all per queue ones. */
 	uint64_t tx_offload_capa;
-	/**< Device per port TX offload capabilities. */
+	/**< Tx offload capabilities including all per port ones
+		and all per queue ones. */
 	uint64_t rx_queue_offload_capa;
 	/**< Device per queue RX offload capabilities. */
 	uint64_t tx_queue_offload_capa;
-- 
2.7.5



More information about the dev mailing list